@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2008-2024 Jonathan Schleifer <js@nil.im>
+ * Copyright (c) 2008-2025 Jonathan Schleifer <js@nil.im>
  *
  * All rights reserved.
  *
@@ -26,6 +26,7 @@
 
 #import "OFConstantString.h"
 #import "OFUTF8String.h"
+#import "OFUTF8String+Private.h"
 
 #import "OFInitializationFailedException.h"
 #import "OFInvalidEncodingException.h"
@@ -97,8 +98,8 @@ OF_SINGLETON_METHODS
 		ivars->cString = _cString;
 		ivars->cStringLength = _cStringLength;
 
-		switch (OFUTF8StringCheck(ivars->cString, ivars->cStringLength,
-		    &ivars->length)) {
+		switch (_OFUTF8StringCheck(ivars->cString, ivars->cStringLength,
+		    &ivars->length, &ivars->containsNull)) {
 		case 1:
 			ivars->isUTF8 = true;
 			break;
