@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2008-2024 Jonathan Schleifer <js@nil.im>
+ * Copyright (c) 2008-2025 Jonathan Schleifer <js@nil.im>
  *
  * All rights reserved.
  *
@@ -55,16 +55,6 @@
 @implementation OFDatagramSocket
 @synthesize delegate = _delegate;
 
-+ (void)initialize
-{
-	if (self != [OFDatagramSocket class])
-		return;
-
-	if (!OFSocketInit())
-		@throw [OFInitializationFailedException
-		    exceptionWithClass: self];
-}
-
 + (instancetype)socket
 {
 	return [[[self alloc] init] autorelease];
@@ -80,6 +70,10 @@
 			abort();
 		}
 
+		if (!_OFSocketInit())
+			@throw [OFInitializationFailedException
+			    exceptionWithClass: self.class];
+
 		_socket = OFInvalidSocketHandle;
 #ifdef OF_HAVE_AMIGAOS
 		_socketID = -1;
@@ -136,7 +130,7 @@
 	if (ioctlsocket(_socket, FIONBIO, &v) == SOCKET_ERROR)
 		@throw [OFSetOptionFailedException
 		    exceptionWithObject: self
-				  errNo: OFSocketErrNo()];
+				  errNo: _OFSocketErrNo()];
 
 	_canBlock = canBlock;
 #else
@@ -152,7 +146,7 @@
 	    (char *)&v, (socklen_t)sizeof(v)) != 0)
 		@throw [OFSetOptionFailedException
 		    exceptionWithObject: self
-				  errNo: OFSocketErrNo()];
+				  errNo: _OFSocketErrNo()];
 
 #ifdef OF_WII
 	_canSendToBroadcastAddresses = canSendToBroadcastAddresses;
@@ -163,13 +157,13 @@
 {
 #ifndef OF_WII
 	int v;
-	socklen_t len = sizeof(v);
+	socklen_t len = (socklen_t)sizeof(v);
 
 	if (getsockopt(_socket, SOL_SOCKET, SO_BROADCAST,
 	    (char *)&v, &len) != 0 || len != sizeof(v))
 		@throw [OFGetOptionFailedException
 		    exceptionWithObject: self
-				  errNo: OFSocketErrNo()];
+				  errNo: _OFSocketErrNo()];
 
 	return v;
 #else
@@ -196,7 +190,7 @@
 		@throw [OFReadFailedException
 		    exceptionWithObject: self
 			requestedLength: length
-				  errNo: OFSocketErrNo()];
+				  errNo: _OFSocketErrNo()];
 #else
 	if (length > INT_MAX)
 		@throw [OFOutOfRangeException exception];
@@ -207,7 +201,7 @@
 		@throw [OFReadFailedException
 		    exceptionWithObject: self
 			requestedLength: length
-				  errNo: OFSocketErrNo()];
+				  errNo: _OFSocketErrNo()];
 #endif
 
 	if (sender != NULL) {
@@ -265,7 +259,7 @@
 						length: length
 						  mode: runLoopMode
 # ifdef OF_HAVE_BLOCKS
-						 block: NULL
+					       handler: NULL
 # endif
 					      delegate: _delegate];
 }
@@ -275,22 +269,55 @@
 			length: (size_t)length
 			 block: (OFDatagramSocketAsyncReceiveBlock)block
 {
+	OFDatagramSocketPacketReceivedHandler handler = ^ bool (
+	    OFDatagramSocket *socket, void *buffer_, size_t length_,
+	    const OFSocketAddress *sender, id exception) {
+		return block(length_, sender, exception);
+	};
+
 	[self asyncReceiveIntoBuffer: buffer
 			      length: length
 			 runLoopMode: OFDefaultRunLoopMode
-			       block: block];
+			     handler: handler];
+}
+
+- (void)asyncReceiveIntoBuffer: (void *)buffer
+			length: (size_t)length
+		       handler: (OFDatagramSocketPacketReceivedHandler)handler
+{
+	[self asyncReceiveIntoBuffer: buffer
+			      length: length
+			 runLoopMode: OFDefaultRunLoopMode
+			     handler: handler];
 }
 
 - (void)asyncReceiveIntoBuffer: (void *)buffer
 			length: (size_t)length
 		   runLoopMode: (OFRunLoopMode)runLoopMode
 			 block: (OFDatagramSocketAsyncReceiveBlock)block
+{
+	OFDatagramSocketPacketReceivedHandler handler = ^ bool (
+	    OFDatagramSocket *socket, void *buffer_, size_t length_,
+	    const OFSocketAddress *sender, id exception) {
+		return block(length_, sender, exception);
+	};
+
+	[self asyncReceiveIntoBuffer: buffer
+			      length: length
+			 runLoopMode: runLoopMode
+			     handler: handler];
+}
+
+- (void)asyncReceiveIntoBuffer: (void *)buffer
+			length: (size_t)length
+		   runLoopMode: (OFRunLoopMode)runLoopMode
+		       handler: (OFDatagramSocketPacketReceivedHandler)handler
 {
 	[OFRunLoop of_addAsyncReceiveForDatagramSocket: self
 						buffer: buffer
 						length: length
 						  mode: runLoopMode
-						 block: block
+					       handler: handler
 					      delegate: nil];
 }
 #endif
@@ -314,7 +341,7 @@
 		    exceptionWithObject: self
 			requestedLength: length
 			   bytesWritten: 0
-				  errNo: OFSocketErrNo()];
+				  errNo: _OFSocketErrNo()];
 #else
 	int bytesWritten;
 
@@ -327,7 +354,7 @@
 		    exceptionWithObject: self
 			requestedLength: length
 			   bytesWritten: 0
-				  errNo: OFSocketErrNo()];
+				  errNo: _OFSocketErrNo()];
 #endif
 
 	if ((size_t)bytesWritten != length)
@@ -354,7 +381,7 @@
 					   receiver: receiver
 					       mode: runLoopMode
 # ifdef OF_HAVE_BLOCKS
-					      block: NULL
+					    handler: NULL
 # endif
 					   delegate: _delegate];
 }
@@ -364,10 +391,26 @@
 	     receiver: (const OFSocketAddress *)receiver
 		block: (OFDatagramSocketAsyncSendDataBlock)block
 {
+	OFDatagramSocketDataSentHandler handler = ^ OFData *(
+	    OFDatagramSocket *socket, OFData *data_,
+	    const OFSocketAddress *receiver_, id exception) {
+		return block(exception);
+	};
+
 	[self asyncSendData: data
 		   receiver: receiver
 		runLoopMode: OFDefaultRunLoopMode
-		      block: block];
+		    handler: handler];
+}
+
+- (void)asyncSendData: (OFData *)data
+	     receiver: (const OFSocketAddress *)receiver
+	      handler: (OFDatagramSocketDataSentHandler)handler
+{
+	[self asyncSendData: data
+		   receiver: receiver
+		runLoopMode: OFDefaultRunLoopMode
+		    handler: handler];
 }
 
 - (void)asyncSendData: (OFData *)data
@@ -375,11 +418,30 @@
 	  runLoopMode: (OFRunLoopMode)runLoopMode
 		block: (OFDatagramSocketAsyncSendDataBlock)block
 {
+	OFDatagramSocketDataSentHandler handler = ^ OFData *(
+	    OFDatagramSocket *socket, OFData *data_,
+	    const OFSocketAddress *receiver_, id exception) {
+		return block(exception);
+	};
+
 	[OFRunLoop of_addAsyncSendForDatagramSocket: self
 					       data: data
 					   receiver: receiver
 					       mode: runLoopMode
-					      block: block
+					    handler: handler
+					   delegate: nil];
+}
+
+- (void)asyncSendData: (OFData *)data
+	     receiver: (const OFSocketAddress *)receiver
+	  runLoopMode: (OFRunLoopMode)runLoopMode
+	      handler: (OFDatagramSocketDataSentHandler)handler
+{
+	[OFRunLoop of_addAsyncSendForDatagramSocket: self
+					       data: data
+					   receiver: receiver
+					       mode: runLoopMode
+					    handler: handler
 					   delegate: nil];
 }
 #endif
