@@ -1,16 +1,20 @@
 /*
- * Copyright (c) 2008-2024 Jonathan Schleifer <js@nil.im>
+ * Copyright (c) 2008-2025 Jonathan Schleifer <js@nil.im>
  *
  * All rights reserved.
  *
- * This file is part of ObjFW. It may be distributed under the terms of the
- * Q Public License 1.0, which can be found in the file LICENSE.QPL included in
- * the packaging of this file.
+ * This program is free software: you can redistribute it and/or modify it
+ * under the terms of the GNU Lesser General Public License version 3.0 only,
+ * as published by the Free Software Foundation.
  *
- * Alternatively, it may be distributed under the terms of the GNU General
- * Public License, either version 2 or 3, which can be found in the file
- * LICENSE.GPLv2 or LICENSE.GPLv3 respectively included in the packaging of this
- * file.
+ * This program is distributed in the hope that it will be useful, but WITHOUT
+ * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+ * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
+ * version 3.0 for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public License
+ * version 3.0 along with this program. If not, see
+ * <https://www.gnu.org/licenses/>.
  */
 
 #include "config.h"
@@ -674,10 +678,11 @@ OF_SINGLETON_METHODS
 {
 	OFMutableString *JSON = [OFMutableString stringWithString: @"{"];
 	void *pool = objc_autoreleasePoolPush();
-	OFEnumerator *keyEnumerator = [self keyEnumerator];
-	OFEnumerator *objectEnumerator = [self objectEnumerator];
+	OFArray *keys = self.allKeys;
 	size_t i, count = self.count;
-	id key, object;
+
+	if (options & OFJSONRepresentationOptionSorted)
+		keys = keys.sortedArray;
 
 	if (options & OFJSONRepresentationOptionPretty) {
 		OFMutableString *indentation = [OFMutableString string];
@@ -688,9 +693,9 @@ OF_SINGLETON_METHODS
 		[JSON appendString: @"\n"];
 
 		i = 0;
-		while ((key = [keyEnumerator nextObject]) != nil &&
-		    (object = [objectEnumerator nextObject]) != nil) {
+		for (id key in keys) {
 			void *pool2 = objc_autoreleasePoolPush();
+			id object = [self objectForKey: key];
 			int identifierOptions =
 			    options | OFJSONRepresentationOptionIsIdentifier;
 
@@ -718,9 +723,9 @@ OF_SINGLETON_METHODS
 		[JSON appendString: indentation];
 	} else {
 		i = 0;
-		while ((key = [keyEnumerator nextObject]) != nil &&
-		    (object = [objectEnumerator nextObject]) != nil) {
+		for (id key in keys) {
 			void *pool2 = objc_autoreleasePoolPush();
+			id object = [self objectForKey: key];
 			int identifierOptions =
 			    options | OFJSONRepresentationOptionIsIdentifier;
 
