@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2008-2024 Jonathan Schleifer <js@nil.im>
+ * Copyright (c) 2008-2025 Jonathan Schleifer <js@nil.im>
  *
  * All rights reserved.
  *
@@ -26,7 +26,9 @@
 #import "OFEmbeddedIRIHandler.h"
 #import "OFIRI.h"
 #import "OFMemoryStream.h"
+#import "OFNumber.h"
 
+#import "OFGetItemAttributesFailedException.h"
 #import "OFInvalidArgumentException.h"
 #import "OFOpenItemFailedException.h"
 
@@ -35,12 +37,12 @@
 # import "OFPlainMutex.h"
 #endif
 
-struct EmbeddedFile {
+static struct EmbeddedFile {
 	OFString *path;
 	const uint8_t *bytes;
 	size_t size;
 } *embeddedFiles = NULL;
-size_t numEmbeddedFiles = 0;
+static size_t numEmbeddedFiles = 0;
 #ifdef OF_HAVE_THREADS
 static OFPlainMutex mutex;
 static OFOnceControl mutexOnceControl = OFOnceControlInitValue;
@@ -126,4 +128,45 @@ OFRegisterEmbeddedFile(OFString *path, const uint8_t *bytes, size_t size)
 						      mode: mode
 						     errNo: ENOENT];
 }
+
+- (OFFileAttributes)attributesOfItemAtIRI: (OFIRI *)IRI
+{
+	OFString *path;
+
+	if (![IRI.scheme isEqual: @"embedded"] || IRI.host.length > 0 ||
+	    IRI.port != nil || IRI.user != nil || IRI.password != nil ||
+	    IRI.query != nil || IRI.fragment != nil)
+		@throw [OFInvalidArgumentException exception];
+
+	if ((path = IRI.path) == nil) {
+		@throw [OFInvalidArgumentException exception];
+	}
+
+#ifdef OF_HAVE_THREADS
+	OFEnsure(OFPlainMutexLock(&mutex) == 0);
+	@try {
+#endif
+		for (size_t i = 0; i < numEmbeddedFiles; i++) {
+			OFNumber *fileSize;
+
+			if (![embeddedFiles[i].path isEqual: path])
+				continue;
+
+			fileSize = [OFNumber numberWithUnsignedLongLong:
+			    embeddedFiles[i].size];
+
+			return [OFDictionary dictionaryWithKeysAndObjects:
+			    OFFileSize, fileSize,
+			    OFFileType, OFFileTypeRegular,
+			    nil];
+		}
+#ifdef OF_HAVE_THREADS
+	} @finally {
+		OFEnsure(OFPlainMutexUnlock(&mutex) == 0);
+	}
+#endif
+
+	@throw [OFGetItemAttributesFailedException exceptionWithIRI: IRI
+							      errNo: ENOENT];
+}
 @end
