@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2008-2024 Jonathan Schleifer <js@nil.im>
+ * Copyright (c) 2008-2025 Jonathan Schleifer <js@nil.im>
  *
  * All rights reserved.
  *
@@ -33,8 +33,12 @@
 #import "OFHTTPRequest.h"
 #import "OFHTTPResponse.h"
 #import "OFIRI.h"
+#import "OFIRI+Private.h"
 #import "OFNumber.h"
+#import "OFSocket.h"
 #import "OFSocket+Private.h"
+#import "OFString.h"
+#import "OFString+Private.h"
 #import "OFTCPSocket.h"
 #import "OFThread.h"
 #import "OFTimer.h"
@@ -477,8 +481,19 @@ normalizedKey(OFString *key)
 				   options: OFStringSearchBackwards].location;
 
 		if (pos != OFNotFound) {
+			OFString *host = [value substringToIndex: pos];
+
+			if ([host hasPrefix: @"["] && [host hasSuffix: @"]"]) {
+				OFString *IPv6 = [host substringWithRange:
+				    OFMakeRange(1, host.length - 2)];
+
+				if (_OFIRIIsIPv6Host(IPv6))
+					host = IPv6;
+
+			}
+
 			[_host release];
-			_host = [[value substringToIndex: pos] retain];
+			_host = [host retain];
 
 			@try {
 				unsigned long long portTmp =
