@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2008-2024 Jonathan Schleifer <js@nil.im>
+ * Copyright (c) 2008-2025 Jonathan Schleifer <js@nil.im>
  *
  * All rights reserved.
  *
@@ -27,6 +27,7 @@
 #import "OFIRI.h"
 #import "OFNumber.h"
 #import "OFString.h"
+#import "OFString+Private.h"
 
 #import "OFOnce.h"
 
@@ -62,7 +63,7 @@ static void
 parseLocale(char *locale, OFStringEncoding *encoding,
     OFString **languageCode, OFString **countryCode)
 {
-	locale = OFStrDup(locale);
+	locale = _OFStrDup(locale);
 
 	@try {
 		OFStringEncoding enc = OFStringEncodingASCII;
