@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2008-2024 Jonathan Schleifer <js@nil.im>
+ * Copyright (c) 2008-2025 Jonathan Schleifer <js@nil.im>
  *
  * All rights reserved.
  *
@@ -54,7 +54,7 @@ OF_DIRECT_MEMBERS
 	unsigned char _node[IPX_NODE_LEN];
 	uint16_t _port;
 #ifdef OF_HAVE_BLOCKS
-	OFSPXSocketAsyncConnectBlock _block;
+	OFSPXSocketConnectedHandler _handler;
 #endif
 }
 
@@ -63,7 +63,7 @@ OF_DIRECT_MEMBERS
 			  node: (const unsigned char [IPX_NODE_LEN])node
 			  port: (uint16_t)port
 #ifdef OF_HAVE_BLOCKS
-			 block: (OFSPXSocketAsyncConnectBlock)block
+		       handler: (OFSPXSocketConnectedHandler)handler
 #endif
 ;
 - (void)startWithRunLoopMode: (OFRunLoopMode)runLoopMode;
@@ -75,7 +75,7 @@ OF_DIRECT_MEMBERS
 			  node: (const unsigned char [IPX_NODE_LEN])node
 			  port: (uint16_t)port
 #ifdef OF_HAVE_BLOCKS
-			 block: (OFSPXSocketAsyncConnectBlock)block
+		       handler: (OFSPXSocketConnectedHandler)handler
 #endif
 {
 	self = [super init];
@@ -86,7 +86,7 @@ OF_DIRECT_MEMBERS
 		memcpy(_node, node, IPX_NODE_LEN);
 		_port = port;
 #ifdef OF_HAVE_BLOCKS
-		_block = [block copy];
+		_handler = [handler copy];
 #endif
 	} @catch (id e) {
 		[self release];
@@ -100,7 +100,7 @@ OF_DIRECT_MEMBERS
 {
 	[_socket release];
 #ifdef OF_HAVE_BLOCKS
-	[_block release];
+	[_handler release];
 #endif
 
 	[super dealloc];
@@ -152,8 +152,8 @@ inform_delegate:
 		((OFSPXSocket *)sock).canBlock = true;
 
 #ifdef OF_HAVE_BLOCKS
-	if (_block != NULL)
-		_block(exception);
+	if (_handler != NULL)
+		_handler(_socket, _network, _node, _port, exception);
 	else {
 #endif
 		if ([delegate respondsToSelector:
@@ -194,7 +194,7 @@ inform_delegate:
 	if ((_socket = socket(address->sockaddr.ipx.sipx_family,
 	    SOCK_SEQPACKET | SOCK_CLOEXEC, NSPROTO_SPX)) ==
 	    OFInvalidSocketHandle) {
-		*errNo = OFSocketErrNo();
+		*errNo = _OFSocketErrNo();
 		return false;
 	}
 
@@ -214,7 +214,7 @@ inform_delegate:
 
 	if (connect(_socket, (struct sockaddr *)&address->sockaddr,
 	    address->length) != 0) {
-		*errNo = OFSocketErrNo();
+		*errNo = _OFSocketErrNo();
 		return false;
 	}
 
@@ -277,7 +277,7 @@ inform_delegate:
 		      node: node
 		      port: port
 #ifdef OF_HAVE_BLOCKS
-		     block: NULL
+		   handler: NULL
 #endif
 	    ] autorelease] startWithRunLoopMode: runLoopMode];
 
@@ -290,11 +290,29 @@ inform_delegate:
 			 port: (uint16_t)port
 			block: (OFSPXSocketAsyncConnectBlock)block
 {
+	OFSPXSocketConnectedHandler handler = ^ (OFSPXSocket *socket,
+	    uint32_t network_, const unsigned char node_[IPX_NODE_LEN],
+	    uint16_t port_, id exception) {
+		block(exception);
+	};
+
 	[self asyncConnectToNetwork: network
 			       node: node
 			       port: port
 			runLoopMode: OFDefaultRunLoopMode
-			      block: block];
+			    handler: handler];
+}
+
+- (void)asyncConnectToNetwork: (uint32_t)network
+			 node: (const unsigned char [IPX_NODE_LEN])node
+			 port: (uint16_t)port
+		      handler: (OFSPXSocketConnectedHandler)handler
+{
+	[self asyncConnectToNetwork: network
+			       node: node
+			       port: port
+			runLoopMode: OFDefaultRunLoopMode
+			    handler: handler];
 }
 
 - (void)asyncConnectToNetwork: (uint32_t)network
@@ -302,6 +320,25 @@ inform_delegate:
 			 port: (uint16_t)port
 		  runLoopMode: (OFRunLoopMode)runLoopMode
 			block: (OFSPXSocketAsyncConnectBlock)block
+{
+	OFSPXSocketConnectedHandler handler = ^ (OFSPXSocket *socket,
+	    uint32_t network_, const unsigned char node_[IPX_NODE_LEN],
+	    uint16_t port_, id exception) {
+		block(exception);
+	};
+
+	[self asyncConnectToNetwork: network
+			       node: node
+			       port: port
+			runLoopMode: runLoopMode
+			    handler: handler];
+}
+
+- (void)asyncConnectToNetwork: (uint32_t)network
+			 node: (const unsigned char [IPX_NODE_LEN])node
+			 port: (uint16_t)port
+		  runLoopMode: (OFRunLoopMode)runLoopMode
+		      handler: (OFSPXSocketConnectedHandler)handler
 {
 	void *pool = objc_autoreleasePoolPush();
 
@@ -310,7 +347,7 @@ inform_delegate:
 		   network: network
 		      node: node
 		      port: port
-		     block: block
+		   handler: handler
 	    ] autorelease] startWithRunLoopMode: runLoopMode];
 
 	objc_autoreleasePoolPop(pool);
@@ -340,7 +377,7 @@ inform_delegate:
 				    port: port
 			      packetType: SPXPacketType
 				  socket: self
-				   errNo: OFSocketErrNo()];
+				   errNo: _OFSocketErrNo()];
 
 	_canBlock = true;
 
@@ -351,7 +388,7 @@ inform_delegate:
 
 	if (bind(_socket, (struct sockaddr *)&address.sockaddr,
 	    address.length) != 0) {
-		int errNo = OFSocketErrNo();
+		int errNo = _OFSocketErrNo();
 
 		closesocket(_socket);
 		_socket = OFInvalidSocketHandle;
@@ -369,9 +406,9 @@ inform_delegate:
 	address.family = OFSocketAddressFamilyIPX;
 	address.length = (socklen_t)sizeof(address.sockaddr);
 
-	if (OFGetSockName(_socket, (struct sockaddr *)&address.sockaddr,
+	if (_OFGetSockName(_socket, (struct sockaddr *)&address.sockaddr,
 	    &address.length) != 0) {
-		int errNo = OFSocketErrNo();
+		int errNo = _OFSocketErrNo();
 
 		closesocket(_socket);
 		_socket = OFInvalidSocketHandle;
