@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2008-2024 Jonathan Schleifer <js@nil.im>
+ * Copyright (c) 2008-2025 Jonathan Schleifer <js@nil.im>
  *
  * All rights reserved.
  *
@@ -242,7 +242,7 @@
 	if (events < 0)
 		@throw [OFObserveKernelEventsFailedException
 		    exceptionWithObserver: self
-				    errNo: OFSocketErrNo()];
+				    errNo: _OFSocketErrNo()];
 
 #ifdef OF_AMIGAOS
 	if (execSignalMask != 0 &&
