@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2008-2024 Jonathan Schleifer <js@nil.im>
+ * Copyright (c) 2008-2025 Jonathan Schleifer <js@nil.im>
  *
  * All rights reserved.
  *
@@ -51,16 +51,6 @@
 @implementation OFSequencedPacketSocket
 @synthesize listening = _listening, delegate = _delegate;
 
-+ (void)initialize
-{
-	if (self != [OFSequencedPacketSocket class])
-		return;
-
-	if (!OFSocketInit())
-		@throw [OFInitializationFailedException
-		    exceptionWithClass: self];
-}
-
 + (instancetype)socket
 {
 	return [[[self alloc] init] autorelease];
@@ -76,6 +66,10 @@
 			abort();
 		}
 
+		if (!_OFSocketInit())
+			@throw [OFInitializationFailedException
+			    exceptionWithClass: self.class];
+
 		_socket = OFInvalidSocketHandle;
 		_canBlock = true;
 	} @catch (id e) {
@@ -98,11 +92,11 @@
 - (int)of_socketError
 {
 	int errNo;
-	socklen_t len = sizeof(errNo);
+	socklen_t len = (socklen_t)sizeof(errNo);
 
 	if (getsockopt(_socket, SOL_SOCKET, SO_ERROR, (char *)&errNo,
 	    &len) != 0)
-		return OFSocketErrNo();
+		return _OFSocketErrNo();
 
 	return errNo;
 }
@@ -143,7 +137,7 @@
 	if (ioctlsocket(_socket, FIONBIO, &v) == SOCKET_ERROR)
 		@throw [OFSetOptionFailedException
 		    exceptionWithObject: self
-				  errNo: OFSocketErrNo()];
+				  errNo: _OFSocketErrNo()];
 
 	_canBlock = canBlock;
 #else
@@ -163,7 +157,7 @@
 		@throw [OFReadFailedException
 		    exceptionWithObject: self
 			requestedLength: length
-				  errNo: OFSocketErrNo()];
+				  errNo: _OFSocketErrNo()];
 #else
 	if (length > INT_MAX)
 		@throw [OFOutOfRangeException exception];
@@ -172,7 +166,7 @@
 		@throw [OFReadFailedException
 		    exceptionWithObject: self
 			requestedLength: length
-				  errNo: OFSocketErrNo()];
+				  errNo: _OFSocketErrNo()];
 #endif
 
 	return ret;
@@ -194,7 +188,7 @@
 						       length: length
 							 mode: runLoopMode
 # ifdef OF_HAVE_BLOCKS
-							block: NULL
+						      handler: NULL
 # endif
 						     delegate: _delegate];
 }
@@ -204,10 +198,27 @@
 			length: (size_t)length
 			 block: (OFSequencedPacketSocketAsyncReceiveBlock)block
 {
+	OFSequencedPacketSocketPacketReceivedHandler handler = ^ (
+	    OFSequencedPacketSocket *socket, void *buffer_, size_t length_,
+	    id exception) {
+		return block(length_, exception);
+	};
+
 	[self asyncReceiveIntoBuffer: buffer
 			      length: length
 			 runLoopMode: OFDefaultRunLoopMode
-			       block: block];
+			     handler: handler];
+}
+
+- (void)asyncReceiveIntoBuffer: (void *)buffer
+			length: (size_t)length
+		       handler: (OFSequencedPacketSocketPacketReceivedHandler)
+				    handler
+{
+	[self asyncReceiveIntoBuffer: buffer
+			      length: length
+			 runLoopMode: OFDefaultRunLoopMode
+			     handler: handler];
 }
 
 - (void)
@@ -216,11 +227,32 @@
 	       runLoopMode: (OFRunLoopMode)runLoopMode
 		     block: (OFSequencedPacketSocketAsyncReceiveBlock)block
 {
+	OFSequencedPacketSocketPacketReceivedHandler handler = ^ (
+	    OFSequencedPacketSocket *socket, void *buffer_, size_t length_,
+	    id exception) {
+		return block(length_, exception);
+	};
+
 	[OFRunLoop of_addAsyncReceiveForSequencedPacketSocket: self
 						       buffer: buffer
 						       length: length
 							 mode: runLoopMode
-							block: block
+						      handler: handler
+						     delegate: nil];
+}
+
+- (void)asyncReceiveIntoBuffer: (void *)buffer
+			length: (size_t)length
+		   runLoopMode: (OFRunLoopMode)runLoopMode
+		       handler: (OFSequencedPacketSocketPacketReceivedHandler)
+				    handler
+
+{
+	[OFRunLoop of_addAsyncReceiveForSequencedPacketSocket: self
+						       buffer: buffer
+						       length: length
+							 mode: runLoopMode
+						      handler: handler
 						     delegate: nil];
 }
 #endif
@@ -241,7 +273,7 @@
 		    exceptionWithObject: self
 			requestedLength: length
 			   bytesWritten: 0
-				  errNo: OFSocketErrNo()];
+				  errNo: _OFSocketErrNo()];
 #else
 	int bytesWritten;
 
@@ -253,7 +285,7 @@
 		    exceptionWithObject: self
 			requestedLength: length
 			   bytesWritten: 0
-				  errNo: OFSocketErrNo()];
+				  errNo: _OFSocketErrNo()];
 #endif
 
 	if ((size_t)bytesWritten != length)
@@ -274,7 +306,7 @@
 						      data: data
 						      mode: runLoopMode
 # ifdef OF_HAVE_BLOCKS
-						     block: NULL
+						   handler: NULL
 # endif
 						  delegate: _delegate];
 }
@@ -283,19 +315,46 @@
 - (void)asyncSendData: (OFData *)data
 		block: (OFSequencedPacketSocketAsyncSendDataBlock)block
 {
+	OFSequencedPacketSocketDataSentHandler handler = ^ (
+	    OFSequencedPacketSocket *socket, OFData *data_, id exception) {
+		return block(exception);
+	};
+
 	[self asyncSendData: data
 		runLoopMode: OFDefaultRunLoopMode
-		      block: block];
+		    handler: handler];
+}
+
+- (void)asyncSendData: (OFData *)data
+		handler: (OFSequencedPacketSocketDataSentHandler)handler
+{
+	[self asyncSendData: data
+		runLoopMode: OFDefaultRunLoopMode
+		    handler: handler];
 }
 
 - (void)asyncSendData: (OFData *)data
 	  runLoopMode: (OFRunLoopMode)runLoopMode
 		block: (OFSequencedPacketSocketAsyncSendDataBlock)block
+{
+	OFSequencedPacketSocketDataSentHandler handler = ^ (
+	    OFSequencedPacketSocket *socket, OFData *data_, id exception) {
+		return block(exception);
+	};
+
+	[self asyncSendData: data
+		runLoopMode: runLoopMode
+		    handler: handler];
+}
+
+- (void)asyncSendData: (OFData *)data
+	  runLoopMode: (OFRunLoopMode)runLoopMode
+	      handler: (OFSequencedPacketSocketDataSentHandler)handler
 {
 	[OFRunLoop of_addAsyncSendForSequencedPacketSocket: self
 						      data: data
 						      mode: runLoopMode
-						     block: block
+						   handler: handler
 						  delegate: nil];
 }
 #endif
@@ -314,7 +373,7 @@
 		@throw [OFListenOnSocketFailedException
 		    exceptionWithSocket: self
 				backlog: backlog
-				  errNo: OFSocketErrNo()];
+				  errNo: _OFSocketErrNo()];
 
 	_listening = true;
 }
@@ -342,7 +401,7 @@
 	    OFInvalidSocketHandle)
 		@throw [OFAcceptSocketFailedException
 		    exceptionWithSocket: self
-				  errNo: OFSocketErrNo()];
+				  errNo: _OFSocketErrNo()];
 #elif defined(HAVE_ACCEPT4) && defined(SOCK_CLOEXEC)
 	if ((client->_socket = accept4(_socket,
 	    (struct sockaddr *)&client->_remoteAddress.sockaddr,
@@ -350,14 +409,14 @@
 	    OFInvalidSocketHandle)
 		@throw [OFAcceptSocketFailedException
 		    exceptionWithSocket: self
-				  errNo: OFSocketErrNo()];
+				  errNo: _OFSocketErrNo()];
 #else
 	if ((client->_socket = accept(_socket,
 	    (struct sockaddr *)&client->_remoteAddress.sockaddr,
 	    &client->_remoteAddress.length)) == OFInvalidSocketHandle)
 		@throw [OFAcceptSocketFailedException
 		    exceptionWithSocket: self
-				  errNo: OFSocketErrNo()];
+				  errNo: _OFSocketErrNo()];
 
 # if defined(HAVE_FCNTL) && defined(FD_CLOEXEC)
 	if ((flags = fcntl(client->_socket, F_GETFD, 0)) != -1)
@@ -378,6 +437,11 @@
 		client->_remoteAddress.family = OFSocketAddressFamilyIPv6;
 		break;
 #endif
+#ifdef OF_HAVE_UNIX_SOCKETS
+	case AF_UNIX:
+		client->_remoteAddress.family = OFSocketAddressFamilyUNIX;
+		break;
+#endif
 #ifdef OF_HAVE_IPX
 	case AF_IPX:
 		client->_remoteAddress.family = OFSocketAddressFamilyIPX;
@@ -400,23 +464,50 @@
 {
 	[OFRunLoop of_addAsyncAcceptForSocket: self
 					 mode: runLoopMode
-					block: NULL
+				      handler: NULL
 				     delegate: _delegate];
 }
 
 #ifdef OF_HAVE_BLOCKS
 - (void)asyncAcceptWithBlock: (OFSequencedPacketSocketAsyncAcceptBlock)block
 {
-	[self asyncAcceptWithRunLoopMode: OFDefaultRunLoopMode block: block];
+	OFSequencedPacketSocketAcceptedHandler handler = ^ (
+	    OFSequencedPacketSocket *socket,
+	    OFSequencedPacketSocket *acceptedSocket, id exception) {
+		return block(acceptedSocket, exception);
+	};
+
+	[self asyncAcceptWithRunLoopMode: OFDefaultRunLoopMode
+				 handler: handler];
+}
+
+- (void)asyncAcceptWithHandler: (OFSequencedPacketSocketAcceptedHandler)handler
+{
+	[self asyncAcceptWithRunLoopMode: OFDefaultRunLoopMode
+				 handler: handler];
 }
 
 - (void)
     asyncAcceptWithRunLoopMode: (OFRunLoopMode)runLoopMode
 			 block: (OFSequencedPacketSocketAsyncAcceptBlock)block
+{
+	OFSequencedPacketSocketAcceptedHandler handler = ^ (
+	    OFSequencedPacketSocket *socket,
+	    OFSequencedPacketSocket *acceptedSocket, id exception) {
+		return block(acceptedSocket, exception);
+	};
+
+	[self asyncAcceptWithRunLoopMode: runLoopMode
+				 handler: handler];
+}
+
+- (void)
+    asyncAcceptWithRunLoopMode: (OFRunLoopMode)runLoopMode
+		       handler: (OFSequencedPacketSocketAcceptedHandler)handler
 {
 	[OFRunLoop of_addAsyncAcceptForSocket: self
 					 mode: runLoopMode
-					block: block
+				      handler: handler
 				     delegate: nil];
 }
 #endif
