@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2008-2024 Jonathan Schleifer <js@nil.im>
+ * Copyright (c) 2008-2025 Jonathan Schleifer <js@nil.im>
  *
  * All rights reserved.
  *
@@ -30,6 +30,8 @@
 
 #include <errno.h>
 
+#import "OFSocket.h"
+#import "OFSocket+Private.h"
 #import "OFArray.h"
 #import "OFCharacterSet.h"
 #import "OFLocale.h"
@@ -37,8 +39,6 @@
 # import "OFMutex.h"
 #endif
 #import "OFOnce.h"
-#import "OFSocket.h"
-#import "OFSocket+Private.h"
 #import "OFString.h"
 #ifdef OF_HAVE_THREADS
 # import "OFTLSKey.h"
@@ -88,9 +88,9 @@ static bool initSuccessful = false;
 
 #ifdef OF_AMIGAOS
 # if defined(OF_HAVE_THREADS) && !defined(OF_MORPHOS)
-OFTLSKey OFSocketBaseKey;
+OFTLSKey _OFSocketBaseKey;
 #  ifdef OF_AMIGAOS4
-OFTLSKey OFSocketInterfaceKey;
+OFTLSKey _OFSocketInterfaceKey;
 #  endif
 # else
 struct Library *SocketBase;
@@ -103,11 +103,11 @@ struct SocketIFace *ISocket = NULL;
 #if defined(OF_HAVE_THREADS) && defined(OF_AMIGAOS) && !defined(OF_MORPHOS)
 OF_CONSTRUCTOR()
 {
-	if (OFTLSKeyNew(&OFSocketBaseKey) != 0)
+	if (OFTLSKeyNew(&_OFSocketBaseKey) != 0)
 		@throw [OFInitializationFailedException exception];
 
 # ifdef OF_AMIGAOS4
-	if (OFTLSKeyNew(&OFSocketInterfaceKey) != 0)
+	if (OFTLSKeyNew(&_OFSocketInterfaceKey) != 0)
 		@throw [OFInitializationFailedException exception];
 # endif
 }
@@ -176,7 +176,7 @@ OF_DESTRUCTOR()
 #endif
 
 bool
-OFSocketInit(void)
+_OFSocketInit(void)
 {
 #if !defined(OF_AMIGAOS) || defined(OF_MORPHOS) || !defined(OF_HAVE_THREADS)
 	static OFOnceControl onceControl = OFOnceControlInitValue;
@@ -190,9 +190,9 @@ OFSocketInit(void)
 # endif
 
 # ifdef OF_AMIGAOS4
-	if ((socketInterface = OFTLSKeyGet(OFSocketInterfaceKey)) != NULL)
+	if ((socketInterface = OFTLSKeyGet(_OFSocketInterfaceKey)) != NULL)
 # else
-	if ((socketBase = OFTLSKeyGet(OFSocketBaseKey)) != NULL)
+	if ((socketBase = OFTLSKeyGet(_OFSocketBaseKey)) != NULL)
 # endif
 		return true;
 
@@ -207,7 +207,7 @@ OFSocketInit(void)
 	}
 # endif
 
-	if (OFTLSKeySet(OFSocketBaseKey, socketBase) != 0) {
+	if (OFTLSKeySet(_OFSocketBaseKey, socketBase) != 0) {
 		CloseLibrary(socketBase);
 # ifdef OF_AMIGAOS4
 		DropInterface((struct Interface *)socketInterface);
@@ -216,7 +216,7 @@ OFSocketInit(void)
 	}
 
 # ifdef OF_AMIGAOS4
-	if (OFTLSKeySet(OFSocketInterfaceKey, socketInterface) != 0) {
+	if (OFTLSKeySet(_OFSocketInterfaceKey, socketInterface) != 0) {
 		CloseLibrary(socketBase);
 		DropInterface((struct Interface *)socketInterface);
 		return false;
@@ -229,11 +229,12 @@ OFSocketInit(void)
 
 #if defined(OF_HAVE_THREADS) && defined(OF_AMIGAOS) && !defined(OF_MORPHOS)
 void
-OFSocketDeinit(void)
+_OFSocketDeinit(void)
 {
-	struct Library *socketBase = OFTLSKeyGet(OFSocketBaseKey);
+	struct Library *socketBase = OFTLSKeyGet(_OFSocketBaseKey);
 # ifdef OF_AMIGAOS4
-	struct SocketIFace *socketInterface = OFTLSKeyGet(OFSocketInterfaceKey);
+	struct SocketIFace *socketInterface =
+	    OFTLSKeyGet(_OFSocketInterfaceKey);
 
 	if (socketInterface != NULL)
 		DropInterface((struct Interface *)socketInterface);
@@ -244,7 +245,7 @@ OFSocketDeinit(void)
 #endif
 
 int
-OFSocketErrNo(void)
+_OFSocketErrNo(void)
 {
 #if defined(OF_WINDOWS)
 	switch (WSAGetLastError()) {
@@ -346,7 +347,7 @@ OFSocketErrNo(void)
 
 #ifndef OF_WII
 int
-OFGetSockName(OFSocketHandle sock, struct sockaddr *restrict addr,
+_OFGetSockName(OFSocketHandle sock, struct sockaddr *restrict addr,
     socklen_t *restrict addrLen)
 {
 	int ret;
@@ -379,7 +380,7 @@ OFSocketAddressParseIPv4(OFString *IPv4, uint16_t port)
 #if defined(OF_WII) || defined(OF_NINTENDO_3DS)
 	ret.length = 8;
 #else
-	ret.length = sizeof(ret.sockaddr.in);
+	ret.length = (socklen_t)sizeof(ret.sockaddr.in);
 #endif
 
 	addrIn->sin_family = AF_INET;
@@ -451,9 +452,8 @@ transformEmbeddedIPv4(OFString *IPv6)
 	if (lastColon == OFNotFound)
 		@throw [OFInvalidFormatException exception];
 
-	IPv4 = [IPv6 substringWithRange:
-	    OFMakeRange(lastColon + 1, IPv6.length - lastColon - 1)];
-	IPv6 = [IPv6 substringWithRange: OFMakeRange(0, lastColon + 1)];
+	IPv4 = [IPv6 substringFromIndex: lastColon + 1];
+	IPv6 = [IPv6 substringToIndex: lastColon + 1];
 
 	address = OFSocketAddressParseIPv4(IPv4, 0);
 	addrIn = &address.sockaddr.in;
@@ -475,7 +475,7 @@ OFSocketAddressParseIPv6(OFString *IPv6, uint16_t port)
 
 	memset(&ret, '\0', sizeof(ret));
 	ret.family = OFSocketAddressFamilyIPv6;
-	ret.length = sizeof(ret.sockaddr.in6);
+	ret.length = (socklen_t)sizeof(ret.sockaddr.in6);
 
 #ifdef AF_INET6
 	addrIn6->sin6_family = AF_INET6;
@@ -618,7 +618,7 @@ OFSocketAddressMakeIPX(uint32_t network, const unsigned char node[IPX_NODE_LEN],
 
 	memset(&ret, '\0', sizeof(ret));
 	ret.family = OFSocketAddressFamilyIPX;
-	ret.length = sizeof(ret.sockaddr.ipx);
+	ret.length = (socklen_t)sizeof(ret.sockaddr.ipx);
 
 #ifdef AF_IPX
 	ret.sockaddr.ipx.sipx_family = AF_IPX;
@@ -641,7 +641,7 @@ OFSocketAddressMakeAppleTalk(uint16_t network, uint8_t node, uint8_t port)
 
 	memset(&ret, '\0', sizeof(ret));
 	ret.family = OFSocketAddressFamilyAppleTalk;
-	ret.length = sizeof(ret.sockaddr.at);
+	ret.length = (socklen_t)sizeof(ret.sockaddr.at);
 
 #ifdef AF_APPLETALK
 	ret.sockaddr.at.sat_family = AF_APPLETALK;
@@ -1052,14 +1052,15 @@ OFSocketAddressIPPort(const OFSocketAddress *address)
 }
 
 OFString *
-OFSocketAddressUNIXPath(const OFSocketAddress *_Nonnull address)
+OFSocketAddressUNIXPath(const OFSocketAddress *address)
 {
 	socklen_t length;
 
 	if (address->family != OFSocketAddressFamilyUNIX)
 		@throw [OFInvalidArgumentException exception];
 
-	length = address->length - offsetof(struct sockaddr_un, sun_path);
+	length =
+	    address->length - (socklen_t)offsetof(struct sockaddr_un, sun_path);
 
 	for (socklen_t i = 0; i < length; i++)
 		if (address->sockaddr.un.sun_path[i] == 0)
