@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2008-2024 Jonathan Schleifer <js@nil.im>
+ * Copyright (c) 2008-2025 Jonathan Schleifer <js@nil.im>
  *
  * All rights reserved.
  *
@@ -149,7 +149,7 @@ static uint16_t defaultSOCKS5Port = 1080;
 	if ((_socket = socket(
 	    ((struct sockaddr *)&address->sockaddr)->sa_family,
 	    SOCK_STREAM | SOCK_CLOEXEC, 0)) == OFInvalidSocketHandle) {
-		*errNo = OFSocketErrNo();
+		*errNo = _OFSocketErrNo();
 		return false;
 	}
 
@@ -170,7 +170,7 @@ static uint16_t defaultSOCKS5Port = 1080;
 	/* Cast needed for AmigaOS, where the argument is declared non-const */
 	if (connect(_socket, (struct sockaddr *)&address->sockaddr,
 	    address->length) != 0) {
-		*errNo = OFSocketErrNo();
+		*errNo = _OFSocketErrNo();
 		return false;
 	}
 
@@ -231,7 +231,7 @@ static uint16_t defaultSOCKS5Port = 1080;
 			      port: port
 			  delegate: _delegate
 #ifdef OF_HAVE_BLOCKS
-			     block: NULL
+			   handler: NULL
 #endif
 		    ] autorelease];
 		host = _SOCKS5Host;
@@ -244,7 +244,7 @@ static uint16_t defaultSOCKS5Port = 1080;
 			    host: host
 			    port: port
 			delegate: delegate
-			   block: NULL
+			 handler: NULL
 	    ] autorelease] startWithRunLoopMode: runLoopMode];
 
 	objc_autoreleasePoolPop(pool);
@@ -255,16 +255,47 @@ static uint16_t defaultSOCKS5Port = 1080;
 		      port: (uint16_t)port
 		     block: (OFTCPSocketAsyncConnectBlock)block
 {
+	OFTCPSocketConnectedHandler handler = ^ (OFTCPSocket *socket,
+	    OFString *host_, uint16_t port_, id exception) {
+		block(exception);
+	};
+
 	[self asyncConnectToHost: host
 			    port: port
 		     runLoopMode: OFDefaultRunLoopMode
-			   block: block];
+			 handler: handler];
+}
+
+- (void)asyncConnectToHost: (OFString *)host
+		      port: (uint16_t)port
+		   handler: (OFTCPSocketConnectedHandler)handler
+{
+	[self asyncConnectToHost: host
+			    port: port
+		     runLoopMode: OFDefaultRunLoopMode
+			 handler: handler];
 }
 
 - (void)asyncConnectToHost: (OFString *)host
 		      port: (uint16_t)port
 	       runLoopMode: (OFRunLoopMode)runLoopMode
 		     block: (OFTCPSocketAsyncConnectBlock)block
+{
+	OFTCPSocketConnectedHandler handler = ^ (OFTCPSocket *socket,
+	    OFString *host_, uint16_t port_, id exception) {
+		block(exception);
+	};
+
+	[self asyncConnectToHost: host
+			    port: port
+		     runLoopMode: runLoopMode
+			 handler: handler];
+}
+
+- (void)asyncConnectToHost: (OFString *)host
+		      port: (uint16_t)port
+	       runLoopMode: (OFRunLoopMode)runLoopMode
+		   handler: (OFTCPSocketConnectedHandler)handler
 {
 	void *pool = objc_autoreleasePoolPush();
 	id <OFTCPSocketDelegate> delegate = nil;
@@ -275,7 +306,7 @@ static uint16_t defaultSOCKS5Port = 1080;
 			      host: host
 			      port: port
 			  delegate: nil
-			     block: block] autorelease];
+			   handler: handler] autorelease];
 		host = _SOCKS5Host;
 		port = _SOCKS5Port;
 	}
@@ -285,7 +316,8 @@ static uint16_t defaultSOCKS5Port = 1080;
 			    host: host
 			    port: port
 			delegate: delegate
-			   block: (delegate == nil ? block : NULL)] autorelease]
+			 handler: (delegate == nil
+				      ? handler : NULL)] autorelease]
 	    startWithRunLoopMode: runLoopMode];
 
 	objc_autoreleasePoolPop(pool);
@@ -323,7 +355,7 @@ static uint16_t defaultSOCKS5Port = 1080;
 		    exceptionWithHost: host
 				 port: port
 			       socket: self
-				errNo: OFSocketErrNo()];
+				errNo: _OFSocketErrNo()];
 
 	_canBlock = true;
 
@@ -340,7 +372,7 @@ static uint16_t defaultSOCKS5Port = 1080;
 #endif
 		if (bind(_socket, (struct sockaddr *)&address.sockaddr,
 		    address.length) != 0) {
-			int errNo = OFSocketErrNo();
+			int errNo = _OFSocketErrNo();
 
 			closesocket(_socket);
 			_socket = OFInvalidSocketHandle;
@@ -367,8 +399,8 @@ static uint16_t defaultSOCKS5Port = 1080;
 			    address.length)) == 0)
 				break;
 
-			if (OFSocketErrNo() != EADDRINUSE) {
-				int errNo = OFSocketErrNo();
+			if (_OFSocketErrNo() != EADDRINUSE) {
+				int errNo = _OFSocketErrNo();
 
 				closesocket(_socket);
 				_socket = OFInvalidSocketHandle;
@@ -387,9 +419,9 @@ static uint16_t defaultSOCKS5Port = 1080;
 	memset(&address, 0, sizeof(address));
 
 	address.length = (socklen_t)sizeof(address.sockaddr);
-	if (OFGetSockName(_socket, (struct sockaddr *)&address.sockaddr,
+	if (_OFGetSockName(_socket, (struct sockaddr *)&address.sockaddr,
 	    &address.length) != 0) {
-		int errNo = OFSocketErrNo();
+		int errNo = _OFSocketErrNo();
 
 		closesocket(_socket);
 		_socket = OFInvalidSocketHandle;
@@ -435,19 +467,19 @@ static uint16_t defaultSOCKS5Port = 1080;
 	    (char *)&v, (socklen_t)sizeof(v)) != 0)
 		@throw [OFSetOptionFailedException
 		    exceptionWithObject: self
-				  errNo: OFSocketErrNo()];
+				  errNo: _OFSocketErrNo()];
 }
 
 - (bool)sendsKeepAlives
 {
 	int v;
-	socklen_t len = sizeof(v);
+	socklen_t len = (socklen_t)sizeof(v);
 
 	if (getsockopt(_socket, SOL_SOCKET, SO_KEEPALIVE,
 	    (char *)&v, &len) != 0 || len != sizeof(v))
 		@throw [OFGetOptionFailedException
 		    exceptionWithObject: self
-				  errNo: OFSocketErrNo()];
+				  errNo: _OFSocketErrNo()];
 
 	return v;
 }
@@ -462,19 +494,19 @@ static uint16_t defaultSOCKS5Port = 1080;
 	    (char *)&v, (socklen_t)sizeof(v)) != 0)
 		@throw [OFSetOptionFailedException
 		    exceptionWithObject: self
-				  errNo: OFSocketErrNo()];
+				  errNo: _OFSocketErrNo()];
 }
 
 - (bool)canDelaySendingSegments
 {
 	int v;
-	socklen_t len = sizeof(v);
+	socklen_t len = (socklen_t)sizeof(v);
 
 	if (getsockopt(_socket, IPPROTO_TCP, TCP_NODELAY,
 	    (char *)&v, &len) != 0 || len != sizeof(v))
 		@throw [OFGetOptionFailedException
 		    exceptionWithObject: self
-				  errNo: OFSocketErrNo()];
+				  errNo: _OFSocketErrNo()];
 
 	return !v;
 }
