@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2008-2024 Jonathan Schleifer <js@nil.im>
+ * Copyright (c) 2008-2025 Jonathan Schleifer <js@nil.im>
  *
  * All rights reserved.
  *
@@ -33,7 +33,7 @@ OF_ASSUME_NONNULL_BEGIN
 	struct OFUTF8StringIvars {
 		char          *cString;
 		size_t        cStringLength;
-		bool          isUTF8;
+		bool          isUTF8, containsNull;
 		size_t        length;
 		bool          hasHash;
 		unsigned long hash;
@@ -43,15 +43,4 @@ OF_ASSUME_NONNULL_BEGIN
 }
 @end
 
-#ifdef __cplusplus
-extern "C" {
-#endif
-extern int _OFUTF8StringCheck(const char *, size_t, size_t *_Nullable)
-    OF_VISIBILITY_HIDDEN;
-extern size_t _OFUTF8StringIndexToPosition(const char *, size_t, size_t)
-    OF_VISIBILITY_HIDDEN;
-#ifdef __cplusplus
-}
-#endif
-
 OF_ASSUME_NONNULL_END
