@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2008-2024 Jonathan Schleifer <js@nil.im>
+ * Copyright (c) 2008-2025 Jonathan Schleifer <js@nil.im>
  *
  * All rights reserved.
  *
@@ -25,9 +25,11 @@
 
 OF_ASSUME_NONNULL_BEGIN
 
+@interface OHLeftJoyCon ()
 #if defined(OF_LINUX) && defined(OF_HAVE_FILES)
-@interface OHLeftJoyCon () <OHEvdevMapping>
-@end
+    <OHEvdevMapping>
 #endif
+- (instancetype)oh_init OF_METHOD_FAMILY(init);
+@end
 
 OF_ASSUME_NONNULL_END
