@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2008-2024 Jonathan Schleifer <js@nil.im>
+ * Copyright (c) 2008-2025 Jonathan Schleifer <js@nil.im>
  *
  * All rights reserved.
  *
@@ -193,7 +193,7 @@ queryNetworkInterfaceAddresses(OFMutableDictionary *ret,
 
 		memset(&ifc, 0, sizeof(ifc));
 		ifc.ifc_buf = (void *)ifrs;
-		ifc.ifc_len = 128 * sizeof(struct ifreq);
+		ifc.ifc_len = 128 * (int)sizeof(struct ifreq);
 		if (ioctl(sock, SIOCGIFCONF, &ifc) < 0)
 			return false;
 
@@ -248,7 +248,7 @@ queryNetworkInterfaceAddresses(OFMutableDictionary *ret,
 			[addresses addItem: &address];
 
 next:
-#  ifdef HAVE_STRUCT_SOCKADDR_SA_LEN
+#  if defined(HAVE_STRUCT_SOCKADDR_SA_LEN) && !defined(OF_NETBSD)
 			if (current->ifr_addr.sa_len > sizeof(struct sockaddr))
 				buffer += sizeof(struct ifreq) -
 				    sizeof(struct sockaddr) +
@@ -656,7 +656,7 @@ queryNetworkInterfaceHardwareAddress(OFMutableDictionary *ret)
 
 		memset(&ifc, 0, sizeof(ifc));
 		ifc.ifc_buf = (void *)ifrs;
-		ifc.ifc_len = 128 * sizeof(struct ifreq);
+		ifc.ifc_len = 128 * (int)sizeof(struct ifreq);
 		if (ioctl(sock, SIOCGIFCONF, &ifc) < 0)
 			return false;
 
