@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2008-2024 Jonathan Schleifer <js@nil.im>
+ * Copyright (c) 2008-2025 Jonathan Schleifer <js@nil.im>
  *
  * All rights reserved.
  *
@@ -51,6 +51,7 @@
 #import "OFData.h"
 #import "OFStdIOStream+Private.h"
 #import "OFString.h"
+#import "OFString+Private.h"
 #import "OFSystemInfo.h"
 
 #import "OFInvalidArgumentException.h"
@@ -71,6 +72,8 @@ codepageToEncoding(UINT codepage)
 		return OFStringEncodingCodepage850;
 	case 858:
 		return OFStringEncodingCodepage858;
+	case 1250:
+		return OFStringEncodingWindows1250;
 	case 1251:
 		return OFStringEncodingWindows1251;
 	case 1252:
@@ -180,7 +183,7 @@ codepageToEncoding(UINT codepage)
 			char UTF8[4];
 			size_t UTF8Len;
 
-			if ((UTF8Len = OFUTF8StringEncode(c, UTF8)) == 0)
+			if ((UTF8Len = _OFUTF8StringEncode(c, UTF8)) == 0)
 				@throw [OFInvalidEncodingException exception];
 
 			if (UTF8Len <= length) {
@@ -237,7 +240,7 @@ codepageToEncoding(UINT codepage)
 				i++;
 			}
 
-			if ((UTF8Len = OFUTF8StringEncode(c, UTF8)) == 0)
+			if ((UTF8Len = _OFUTF8StringEncode(c, UTF8)) == 0)
 				@throw [OFInvalidEncodingException exception];
 
 			if (j + UTF8Len <= length) {
@@ -278,7 +281,7 @@ codepageToEncoding(UINT codepage)
 		size_t toCopy;
 		DWORD UTF16Len, bytesWritten;
 
-		UTF8Len = -OFUTF8StringDecode(
+		UTF8Len = -_OFUTF8StringDecode(
 		    _incompleteUTF8Surrogate, _incompleteUTF8SurrogateLen, &c);
 
 		OFEnsure(UTF8Len > 0);
@@ -294,7 +297,7 @@ codepageToEncoding(UINT codepage)
 		if (_incompleteUTF8SurrogateLen < (size_t)UTF8Len)
 			return 0;
 
-		UTF8Len = OFUTF8StringDecode(
+		UTF8Len = _OFUTF8StringDecode(
 		    _incompleteUTF8Surrogate, _incompleteUTF8SurrogateLen, &c);
 
 		if (UTF8Len <= 0 || c > 0x10FFFF) {
@@ -366,7 +369,7 @@ codepageToEncoding(UINT codepage)
 			OFUnichar c;
 			ssize_t UTF8Len;
 
-			UTF8Len = OFUTF8StringDecode(buffer + i, length - i,
+			UTF8Len = _OFUTF8StringDecode(buffer + i, length - i,
 			    &c);
 
 			if (UTF8Len < 0 && UTF8Len >= -4) {
