@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2008-2024 Jonathan Schleifer <js@nil.im>
+ * Copyright (c) 2008-2025 Jonathan Schleifer <js@nil.im>
  *
  * All rights reserved.
  *
@@ -92,9 +92,19 @@ static SSL_CTX *clientContext;
 	if (_SSL == NULL)
 		@throw [OFNotOpenException exceptionWithObject: self];
 
-	if (_handshakeDone)
+	if (_handshakeDone) {
 		SSL_shutdown(_SSL);
 
+		while (BIO_ctrl_pending(_writeBIO) > 0) {
+			int tmp = BIO_read(_writeBIO, _buffer, bufferSize);
+
+			OFEnsure(tmp >= 0);
+
+			[_underlyingStream writeBuffer: _buffer length: tmp];
+			[_underlyingStream flushWriteBuffer];
+		}
+	}
+
 	SSL_free(_SSL);
 	_SSL = NULL;
 
