@@ -1,16 +1,20 @@
 /*
- * Copyright (c) 2008-2024 Jonathan Schleifer <js@nil.im>
+ * Copyright (c) 2008-2025 Jonathan Schleifer <js@nil.im>
  *
  * All rights reserved.
  *
- * This file is part of ObjFW. It may be distributed under the terms of the
- * Q Public License 1.0, which can be found in the file LICENSE.QPL included in
- * the packaging of this file.
+ * This program is free software: you can redistribute it and/or modify it
+ * under the terms of the GNU Lesser General Public License version 3.0 only,
+ * as published by the Free Software Foundation.
  *
- * Alternatively, it may be distributed under the terms of the GNU General
- * Public License, either version 2 or 3, which can be found in the file
- * LICENSE.GPLv2 or LICENSE.GPLv3 respectively included in the packaging of this
- * file.
+ * This program is distributed in the hope that it will be useful, but WITHOUT
+ * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+ * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
+ * version 3.0 for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public License
+ * version 3.0 along with this program. If not, see
+ * <https://www.gnu.org/licenses/>.
  */
 
 #include "config.h"
@@ -21,7 +25,10 @@
 #import "OFArray.h"
 #import "OFData.h"
 #import "OFDate.h"
+#import "OFFile.h"
 #import "OFFileManager.h"
+#import "OFIRI.h"
+#import "OFIRIHandler.h"
 #import "OFLocale.h"
 #import "OFNumber.h"
 #import "OFPair.h"
@@ -55,6 +62,8 @@ setPermissions(OFString *path, OFZIPArchiveEntry *entry)
 						 ofItemAtPath: path];
 	}
 #endif
+
+	[app quarantineFile: path];
 }
 
 static void
@@ -85,26 +94,26 @@ setModificationDate(OFString *path, OFZIPArchiveEntry *entry)
 		app = (OFArc *)[OFApplication sharedApplication].delegate;
 }
 
-+ (instancetype)archiveWithPath: (OFString *)path
-			 stream: (OF_KINDOF(OFStream *))stream
-			   mode: (OFString *)mode
-		       encoding: (OFStringEncoding)encoding
++ (instancetype)archiveWithIRI: (OFIRI *)IRI
+			stream: (OF_KINDOF(OFStream *))stream
+			  mode: (OFString *)mode
+		      encoding: (OFStringEncoding)encoding
 {
-	return [[[self alloc] initWithPath: path
-				    stream: stream
-				      mode: mode
-				  encoding: encoding] autorelease];
+	return [[[self alloc] initWithIRI: IRI
+				   stream: stream
+				     mode: mode
+				 encoding: encoding] autorelease];
 }
 
-- (instancetype)initWithPath: (OFString *)path
-		      stream: (OF_KINDOF(OFStream *))stream
-			mode: (OFString *)mode
-		    encoding: (OFStringEncoding)encoding
+- (instancetype)initWithIRI: (OFIRI *)IRI
+		     stream: (OF_KINDOF(OFStream *))stream
+		       mode: (OFString *)mode
+		   encoding: (OFStringEncoding)encoding
 {
 	self = [super init];
 
 	@try {
-		_path = [path copy];
+		_archiveIRI = [IRI copy];
 		_archive = [[OFZIPArchive alloc] initWithStream: stream
 							   mode: mode];
 		_archive.delegate = self;
@@ -118,7 +127,7 @@ setModificationDate(OFString *path, OFZIPArchiveEntry *entry)
 
 - (void)dealloc
 {
-	[_path release];
+	[_archiveIRI release];
 	[_archive release];
 
 	[super dealloc];
@@ -128,9 +137,9 @@ setModificationDate(OFString *path, OFZIPArchiveEntry *entry)
 	    wantsPartNumbered: (unsigned int)partNumber
 	       lastPartNumber: (unsigned int)lastPartNumber
 {
-	OFString *path;
+	OFIRI *IRI;
 
-	if ([_path.pathExtension caseInsensitiveCompare: @"zip"] !=
+	if ([_archiveIRI.pathExtension caseInsensitiveCompare: @"zip"] !=
 	    OFOrderedSame)
 		return nil;
 
@@ -138,16 +147,32 @@ setModificationDate(OFString *path, OFZIPArchiveEntry *entry)
 		return nil;
 
 	if (partNumber == lastPartNumber)
-		path = _path;
-	else
-		path = [_path.stringByDeletingPathExtension
-		    stringByAppendingFormat: @".z%02u", partNumber + 1];
+		IRI = _archiveIRI;
+	else {
+		OFMutableIRI *copy = [[_archiveIRI mutableCopy] autorelease];
+		[copy deletePathExtension];
+		[copy appendPathExtension: [OFString
+		    stringWithFormat: @"z%02u", partNumber + 1]];
+		[copy makeImmutable];
+		IRI = copy;
+	}
 
-	return [OFFile fileWithPath: path mode: @"r"];
+	return (OFSeekableStream *)[OFIRIHandler openItemAtIRI: IRI mode: @"r"];
 }
 
 - (void)listFiles
 {
+	if (app->_outputLevel >= 1 && _archive.archiveComment != nil) {
+		[OFStdOut writeLine: OF_LOCALIZED(
+		    @"list_archive_comment",
+		    @"Archive comment:")];
+		[OFStdOut writeString: @"\t"];
+		[OFStdOut writeLine: [_archive.archiveComment
+		    stringByReplacingOccurrencesOfString: @"\n"
+					      withString: @"\n\t"]];
+		[OFStdOut writeLine: @""];
+	}
+
 	for (OFZIPArchiveEntry *entry in _archive.entries) {
 		void *pool = objc_autoreleasePoolPush();
 
@@ -447,15 +472,11 @@ outer_loop_end:
 }
 
 - (void)addFiles: (OFArray OF_GENERIC(OFString *) *)files
+  archiveComment: (OFString *)archiveComment
 {
 	OFFileManager *fileManager = [OFFileManager defaultManager];
 
-	if (files.count < 1) {
-		[OFStdErr writeLine: OF_LOCALIZED(@"add_no_file_specified",
-		    @"Need one or more files to add!")];
-		app->_exitStatus = 1;
-		return;
-	}
+	_archive.archiveComment = archiveComment;
 
 	for (OFString *localFileName in files) {
 		void *pool = objc_autoreleasePoolPush();
