@@ -1,16 +1,20 @@
 /*
- * Copyright (c) 2008-2024 Jonathan Schleifer <js@nil.im>
+ * Copyright (c) 2008-2025 Jonathan Schleifer <js@nil.im>
  *
  * All rights reserved.
  *
- * This file is part of ObjFW. It may be distributed under the terms of the
- * Q Public License 1.0, which can be found in the file LICENSE.QPL included in
- * the packaging of this file.
+ * This program is free software: you can redistribute it and/or modify it
+ * under the terms of the GNU Lesser General Public License version 3.0 only,
+ * as published by the Free Software Foundation.
  *
- * Alternatively, it may be distributed under the terms of the GNU General
- * Public License, either version 2 or 3, which can be found in the file
- * LICENSE.GPLv2 or LICENSE.GPLv3 respectively included in the packaging of this
- * file.
+ * This program is distributed in the hope that it will be useful, but WITHOUT
+ * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+ * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
+ * version 3.0 for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public License
+ * version 3.0 along with this program. If not, see
+ * <https://www.gnu.org/licenses/>.
  */
 
 #include "config.h"
@@ -106,7 +110,7 @@ help(OFStream *stream, bool full, int status)
 		[stream writeString: @"\n"];
 		[stream writeLine: OF_LOCALIZED(@"full_usage",
 		    @"Options:\n    "
-		    @"-b  --body           "
+		    @"-b  --body=          "
 		    @"  Specify the file to send as body\n    "
 		    @"                     "
 		    @"  (- for standard input)\n    "
@@ -116,15 +120,15 @@ help(OFStream *stream, bool full, int status)
 		    @"  Force / overwrite existing file\n    "
 		    @"-h  --help           "
 		    @"  Show this help\n    "
-		    @"-H  --header         "
+		    @"-H  --header=        "
 		    @"  Add a header (e.g. X-Foo:Bar)\n    "
-		    @"-m  --method         "
+		    @"-m  --method=        "
 		    @"  Set the method of the HTTP request\n    "
-		    @"-o  --output         "
+		    @"-o  --output=        "
 		    @"  Specify output file name\n    "
 		    @"-O  --detect-filename"
 		    @"  Do a HEAD request to detect the file name\n    "
-		    @"-P  --proxy          "
+		    @"-P  --proxy=         "
 		    @"  Specify SOCKS5 proxy\n    "
 		    @"-q  --quiet          "
 		    @"  Quiet mode (no output, except errors)\n    "
@@ -373,7 +377,7 @@ fileNameFromContentDisposition(OFString *contentDisposition)
 	method = method.uppercaseString;
 
 	@try {
-		_method = OFHTTPRequestMethodParseName(method);
+		_method = OFHTTPRequestMethodParseString(method);
 	} @catch (OFInvalidArgumentException *e) {
 		[OFStdErr writeLine: OF_LOCALIZED(@"invalid_input_method",
 		    @"%[prog]: Invalid request method %[method]!",
@@ -985,7 +989,7 @@ after_exception_handling:
 			goto next;
 		}
 
-#ifdef OF_LINUX
+#ifdef OF_FILE_MANAGER_SUPPORTS_EXTENDED_ATTRIBUTES
 		@try {
 			OFString *IRIString = request.IRI.string;
 			OFData *downloadedFromData = [OFData
